A function similar to the phyloseq::tax_glom function,
that assembles abundance data at a specified rank. This removes subtaxa and reassigns the
values at the specified rank.
agglomerate_taxmap(obj, rank, validated = FALSE)A taxmap object that has been agglomerated at the specified rank.
This function helps analyzing taxonomic data at intermediate ranks by agglomerating the observation data and the taxmap object.
Other Advanced Metacoder Filters:
cov_filter(),
otu_prevalence_filter(),
otu_proportion_filter(),
taxa_prevalence_filter()
if (FALSE) { # \dontrun{
if(interactive()){
# This example uses data that are no longer available in the MicrobiomeR package,
# however, they can be easily generated with \code{\link{MicrobiomeR}{as_basic_format}}.
library(MicrobiomeR)
basic_silva <- as_MicrobiomeR_format(MicrobiomeR::raw_silva_2, "basic_format")
phylum_obj <- agglomerate_taxmap(obj = basic_silva, rank = "Phylum")
class_obj <- agglomerate_taxmap(obj = basic_silva, rank = "Class")
order_obj <- agglomerate_taxmap(obj = basic_silva, rank = "Order")
}
} # }