Converts a Taxmap object to the specified format.
as_MicrobiomeR_format(obj, format, ...)An object to be converted to a Taxmap object with create_taxmap.
The name of the format to convert the object to.
An optional list of parameters to use in the as_*_format function specified by the format parameter.
A Taxmap object in the specified format.
See the MicrobiomeR_Formats documentation.