Converts the Taxmap object to the phyloseq_format.
as_phyloseq_format(
obj,
otu_table = "otu_abundance",
tax_data = "otu_annotations",
sample_data = "sample_data",
phy_tree = "phy_tree"
)An object to be converted to a Taxmap object with create_taxmap.
The name of the observation table with OTU data. Default: NULL
The name of the observation table with taxonomic annotations. Default: NULL
The name of the observation table with metadata. Default: NULL
The name of the observation data with the phylogenetic tree. Default: NULL
A Taxmap object in the phyloseq_format.
See the MicrobiomeR_Formats documentation.