Get the correlation plot data comparing all of the treatment groups.
correlation_data(obj, primary_rank, secondary_rank = TRUE, wp_value = 0.05)An object to be converted to a Taxmap object with create_taxmap.
A primary rank used to label the points.
The secondary rank used to color the points, Default: TRUE
The wilcoxon p-value cutoff/threshold, Default: 0.05
Data for the correlation plots.
DETAILS
data mask programming,
mutate, filter, arrange
Other Visualizations:
alpha_diversity_plot(),
correlation_plot(),
correlation_plots(),
heat_tree_parameters(),
heat_tree_plots(),
ordination_plot(),
plot_limits(),
save_alpha_diversity_plots(),
save_correlation_plots(),
save_heat_tree_plots(),
save_ordination_plots(),
save_stacked_barplots(),
stacked_barplot(),
stacked_barplots(),
top_coefficients_barplot()
if (FALSE) { # \dontrun{
if(interactive()){
#EXAMPLE1
}
} # }