Create a correlation plot from a metacoder/taxmap object.
correlation_plot(
obj,
primary_rank,
secondary_rank = TRUE,
wp_value = 0.05,
pal_func = NULL,
trans = "logit"
)An object to be converted to a Taxmap object with create_taxmap.
The primary rank used to label the points.
The secondary rank used to color the points. Can be an integer specifying the number of supertaxon ranks above the primary rank or the name of a supertaxon rank. Default: TRUE
The Wilcoxian P-Value used to represent significant points. Default: 0.05
A palette function that returns grDevices::colorRampPalette.
Either the name of a transformation object, or the object itself given to scale_continuous.
Built-in transformations include "asn", "atanh", "boxcox", "exp", "identity", "log", "log10", "log1p",
"log2", "logit", "probability", "probit", "reciprocal", "reverse" and "sqrt".
A 1:1 correlation plot built with ggplot2.
Correlation plots help to better explain the heat tree findings.
create_taxmap, validate_MicrobiomeR_format, correlation_data, plot_limits, get_color_palette
ggplot, aes, geom_polygon, geom_point, labs, scale_continuous, scale_manual, guide_legend, geom_abline
Other Visualizations:
alpha_diversity_plot(),
correlation_data(),
correlation_plots(),
heat_tree_parameters(),
heat_tree_plots(),
ordination_plot(),
plot_limits(),
save_alpha_diversity_plots(),
save_correlation_plots(),
save_heat_tree_plots(),
save_ordination_plots(),
save_stacked_barplots(),
stacked_barplot(),
stacked_barplots(),
top_coefficients_barplot()
if (FALSE) { # \dontrun{
if(interactive()){
# This example uses data that are no longer available in the MicrobiomeR package,
# however, they can be easily generated with \code{\link{MicrobiomeR}{as_analyzed_format}}.
library(MicrobiomeR)
analyzed_silva <- as_MicrobiomeR_format(MicrobiomeR::raw_silva_2, "analyzed_format")
correlation_plot(analyzed_silva, primary_rank = "Class", secondary_rank = "Phylum")
}
} # }