This function allows the user to create a list of multiple correlation plots.
correlation_plots(obj, primary_ranks, secondary_ranks = TRUE, ...)An object to be converted to a Taxmap object with create_taxmap.
A vector of primary ranks used to label the points.
The secondary rank used to color the points. Can be an integer specifying the number of supertaxon ranks above the primary rank or the name of a supertaxon rank. Default: TRUE
An optional list of parameters to use in the correlation_plot function.
A list object containing correlation plots. A pairwise comparison returns a nested list.
This function makes it easier to generate multiple correlation plots at once.
Other Visualizations:
alpha_diversity_plot(),
correlation_data(),
correlation_plot(),
heat_tree_parameters(),
heat_tree_plots(),
ordination_plot(),
plot_limits(),
save_alpha_diversity_plots(),
save_correlation_plots(),
save_heat_tree_plots(),
save_ordination_plots(),
save_stacked_barplots(),
stacked_barplot(),
stacked_barplots(),
top_coefficients_barplot()
if (FALSE) { # \dontrun{
if(interactive()){
# This example uses data that are no longer available in the MicrobiomeR package,
# however, they can be easily generated with \code{\link{MicrobiomeR}{as_analyzed_format}}.
library(MicrobiomeR)
analyzed_silva <- as_MicrobiomeR_format(MicrobiomeR::raw_silva_2, "analyzed_format")
corr_plots <- correlation_plots(analyzed_silva, primary_ranks = c("Phylum", "Class", "Order"),
secondary_ranks = c("Phylum", "Class", "Order", "Family", "Genus"))
# Show a plot
corr_plots$Class$Phylum
}
} # }