A function that handles the conversion of objects to Taxmap (taxa::taxmap) objects.
create_taxmap(obj)An object that contains the data being analyzed. Can be one of the following:
An object generated from the phyloseq package.
An object generated from the metacoder or taxa package.
An RData file generated from the base::save function. Can have an extension of .RData or .rda.
The output generated is a taxa::taxmap object.
This function is used to convert data to metacoder/taxmap objects for microbiome analysis.
This function is used at the beginning of every other function to support multiple types of input
for the obj parameter in those functions. For phyloseq inputs, this function
uses parse_phyloseq when possible and falls back to
an internal parser for known upstream metacoder namespace breakage.
if (FALSE) { # \dontrun{
if(interactive()){
library(MicrobiomeR)
phy_obj <- MicrobiomeR::phyloseq_silva_2
mc_obj <- create_taxmap(phy_obj)
}
} # }