A function for getting multiple heat_tree plots per rank.

heat_tree_plots(obj, rank_list = NULL, title = TRUE, seed = 1, ...)

Arguments

obj

An object to be converted to a Taxmap object with create_taxmap.

rank_list

A vector of ranks used to generate heat_trees. Default: NULL

title

Can be a logical, NULL, or a string. The string can utilize {rank} to dynamically display the rank in the title via glue.

seed

A single integer seed used to make heat-tree layouts reproducible without modifying the caller's RNG state. Use NULL to defer to the current RNG stream.

...

Any of the heat_tree parameters can be used to change the way the heat_tree output is displayed. Please see the heat_tree_parameters documentation for further explanation.

Value

A list of heat_tree plots.

Details

By default, node size represents the number of retained OTUs assigned to each taxon or any of its descendants in the source otu_abundance table. Counts are pooled across samples after upstream filtering and do not represent read abundance.

Examples

if (FALSE) { # \dontrun{
if(interactive()){
# This example uses data that are no longer available in the MicrobiomeR package,
# however, they can be easily generated with \code{\link{MicrobiomeR}{as_analyzed_format}}.
library(MicrobiomeR)
analyzed_silva <- as_MicrobiomeR_format(MicrobiomeR::raw_silva_2, "analyzed_format")
h_trees <- heat_tree_plots(analyzed_silva, rank_list = c("Phylum", "Class"))
h_trees$Class
 }
} # }