Evaluate whether the group(s) has a significant effect on overall gut microbiota composition.

permanova(obj, distance_method = "bray", group = "TreatmentGroup", seed = 1)

Arguments

obj

An object to be converted to a taxmap object with create_taxmap.

distance_method

Use a desired distance method, Default: 'bray'

group

The group or column in the metadata to test upon, Default: 'TreatmentGroup'

seed

A single integer seed used to make PERMANOVA permutations reproducible without modifying the caller's RNG state. Use NULL to defer to the current RNG stream.

Value

Returns a list which includes permanova, anova, coefficients, and top coefficients.

See also

View top_coefficients_barplot to plot the top_coefficients returned from this function. See adonis2 and betadisper to understand more about how the permanova data was generated

Examples

if (FALSE) { # \dontrun{
if (interactive()) {
  library(MicrobiomeR)
  data <- analyzed_silva
  p <- permanova(obj = data, group = "TreatmentGroup")
  p$permanova
}
} # }