Pick an outgroup for rooting a phylogenetic tree.
pick_new_outgroup(unrooted_tree)A new tree with the longest branch as the outgroup.
This function preprocess a phylogenetic tree for rooting by the longest edge. Please see this issue for more details https://github.com/joey711/phyloseq/issues/597.
Other Phylogenetic Tree Manipulators:
root_by_longest_edge(),
root_phyloseq_tree()