This function saves ordination plots stored in a listlike object to an output folder.
save_ordination_plots(ord_plots, format = "tiff", start_path = "output", ...)An output directory that contains ordination plots.
This function creates an appropriate output directory, where it saves publication ready plots.
Other Visualizations:
alpha_diversity_plot(),
correlation_data(),
correlation_plot(),
correlation_plots(),
heat_tree_parameters(),
heat_tree_plots(),
ordination_plot(),
plot_limits(),
save_alpha_diversity_plots(),
save_correlation_plots(),
save_heat_tree_plots(),
save_stacked_barplots(),
stacked_barplot(),
stacked_barplots(),
top_coefficients_barplot()
if (FALSE) { # \dontrun{
if (interactive()) {
}
} # }