A function that returns a color palette function based off of the scico package.
scico_palette(
scico_palette = "batlow",
scico_number = 800,
scico_range = 0:scico_number
)The output of this function is another function (grDevoces::colorRampPalette), which takes a number to generate an interpolated color palette as a character vector.
The purpose of this function is to provide an interpolated scico palette for using with the get_color_palette function.
Other Color Palettes:
combination_palette(),
get_color_palette(),
viridis_magma_palette(),
viridis_palette()
if (FALSE) { # \dontrun{
if(interactive()){
library(MicrobiomeR)
basic_pal <- scico_palette(scico_palette="hawaii")(25)
better_pal <- get_color_palette(pal_func = scico_palette, color_no = 25)
}
} # }