A function that returns a matrix with used for comparing treatment data.

treatment_matrix(obj)

Arguments

obj

An object to be converted to a taxmap object with create_taxmap.

Value

A matrix with each column representing a comparison to be made.

Details

Use this when you want to do pairwise comparisons.

Examples

if (FALSE) { # \dontrun{
if(interactive()){
 #EXAMPLE1
 }
} # }