This function validates that Taxmap objects are in a valid format MicrobiomeR format.
validate_MicrobiomeR_format(
obj,
validated = FALSE,
valid_formats,
force_format = FALSE,
min_or_max = base::max,
...
)A Taxmap object.
This parameter provides a way to override validation steps. Use carefully. Default: FALSE
A vector of formats that are used for validation.
A logical denoting if the selected format is to be forced. Default: FALSE
A base function (min or max) that determines which format is to be forced. This is particularly useful if you provide multiple valid_formats. Min will choose the lowest level format, while max will choose the highest level format. Default: base::max
An optional list of parameters to use in as_MicrobiomeR_format.
If the object is validated, a Taxmap object.
This function can provide a way to check if a taxmap object has undergone a
MicrobiomeR Style Workflow.