Plot the alpha diversity using a violin plot. alpha_diversity_plots generates plots for all alpha diversity measures.
alpha_diversity_plot(
obj,
measure = "Shannon",
group = "TreatmentGroup",
select_otu_table = NULL,
title = NULL
)
alpha_diversity_plots(
obj,
measures = c("Shannon", "GiniSimpson", "InverseSimpson"),
group = "TreatmentGroup"
)An object to be converted to a Taxmap object with create_taxmap.
Select an alpha diversity measure such as Shannon, Fisher, Coverage, GiniSimpson, and InverseSimpson, Default: 'Shannon'
The "TreatmentGroup" or similar grouping or column from your metadata to denote sample groups, Default: 'TreatmentGroup'
DEPRECATED. Choose an otu table to analyze, Default: 'otu_proportions'
The title of the plot, Default: NULL
A list of alpha diversity measures such as Shannon, Fisher, Coverage, GiniSimpson, and InverseSimpson, Default: 'c("Shannon", "GiniSimpson", "InverseSimpson")'
Returns an alpha diversity plot.
Returns a melted dataframe.
Alpha diversity helps to determine the species richness (the number of different species in a sample) or evenness (similar abundance level).
We prefer to use Shannon as it is better for data generated using the QIIME pipeline.
alpha_diversity_measures, diversity, ggviolin
Other Visualizations:
correlation_data(),
correlation_plot(),
correlation_plots(),
heat_tree_parameters(),
heat_tree_plots(),
ordination_plot(),
plot_limits(),
save_alpha_diversity_plots(),
save_correlation_plots(),
save_heat_tree_plots(),
save_ordination_plots(),
save_stacked_barplots(),
stacked_barplot(),
stacked_barplots(),
top_coefficients_barplot()
Other Visualizations:
correlation_data(),
correlation_plot(),
correlation_plots(),
heat_tree_parameters(),
heat_tree_plots(),
ordination_plot(),
plot_limits(),
save_alpha_diversity_plots(),
save_correlation_plots(),
save_heat_tree_plots(),
save_ordination_plots(),
save_stacked_barplots(),
stacked_barplot(),
stacked_barplots(),
top_coefficients_barplot()
if (FALSE) { # \dontrun{
if (interactive()) {
library(MicrobiomeR)
data <- analyzed_silva
plot <- alpha_diversity_plot(obj = data,
measure = "Shannon")
plot
}
} # }