This function allows for ordination (which helps us to distinguish beta diversity relationships) to be plotted as well as for the corresponding data to be returned.
Generate plots for a list of ordination methods and distances.
An object to be converted to a metacoder object with create_taxmap.
Choose an ordination method from 'PCoA', 'CCA', 'NMDS' or 'DPCoA', Default: 'PCoA'
Choose a distance method or use a pre-computed dist-class object, Default: 'wunifrac'
Choose the group or factor of which colors will be mapped to, Default: 'TreatmentGroup'
The title of the plot, Default: NULL
Allows for only ordination data to be generated, Default: FALSE
A list of ordination methods, Default: 'c("PCoA", "NMDS")'
A list of distance methods, Default: 'c("wunifrac", "unifrac", "bray")'
The data table to use in the observation data. Default: "otu_proportions"
By default, it returns an ordination plot.
Returns a melted dataframe.
View save_ordination_plots to save your ordination plot or multiple ordination plots.
Other Visualizations:
alpha_diversity_plot(),
correlation_data(),
correlation_plot(),
correlation_plots(),
heat_tree_parameters(),
heat_tree_plots(),
plot_limits(),
save_alpha_diversity_plots(),
save_correlation_plots(),
save_heat_tree_plots(),
save_ordination_plots(),
save_stacked_barplots(),
stacked_barplot(),
stacked_barplots(),
top_coefficients_barplot()
Other Visualizations:
alpha_diversity_plot(),
correlation_data(),
correlation_plot(),
correlation_plots(),
heat_tree_parameters(),
heat_tree_plots(),
plot_limits(),
save_alpha_diversity_plots(),
save_correlation_plots(),
save_heat_tree_plots(),
save_ordination_plots(),
save_stacked_barplots(),
stacked_barplot(),
stacked_barplots(),
top_coefficients_barplot()
if (FALSE) { # \dontrun{
if (interactive()) {
# An example ordination plot
library(MicrobiomeR)
data <- analyzed_silva
plot <- ordination_plot(obj = data)
plot
}
} # }