A function that returns a matrix with used for comparing treatment data.
treatment_matrix(obj)An object to be converted to a taxmap object with create_taxmap.
A matrix with each column representing a comparison to be made.
Use this when you want to do pairwise comparisons.
if (FALSE) { # \dontrun{
if(interactive()){
#EXAMPLE1
}
} # }