A function for looking at a Taxmap object and returning the identified MicrobiomeR format.
which_format(obj)If the format is verified it returns a character string denoting the identified format.
This function is used to get basic information about the format of the taxmap object that is supplied by the user.